clear
set mem 700m
set more off
set scheme lean1
use africa_data2, clear 
local y = 2 /*set moving average to observation year + y-1 years*/
local name  "Soc Demo Infr  Prod  Envi BS Comm Debt Emerg NG0 Admin Refug  Totc Totd"
local start = 1  /*marks which sector to start with in the list of sectors in `name'*/
local sec= 15  /*number of sectors should equal number of labels in `name'*/

gen a1 = soc_com_const
gen a2 = democ_com_const
gen a3 = ecinfra_com_const
gen a4 = prod_com_const
gen a5 = envirmultisec_com_const
gen a6 = bs_com_const
gen a7 = commod_com_const
gen a8 = debt_com_const
gen a9 = emerg_com_const
gen a10 = NGO_com_const
gen a11 = donoradmin_com_const
gen a12 = refugdonor_com_const
gen a13 = total_com_const
gen a14 = total_disb_const
gen a15 = a13-a2-a12   			/*all economic aid: minus democracy aid and refugee aid*/

*generate per capita totals
local i = `start'
while `i'<=`sec' {
	gen a`i'_pc = a`i'/(wdi_pop*1000)
	local i = `i' +1
}

*rescale totals by $millions
local i = `start'
while `i'<=`sec' {
	replace a`i' = a`i'/1000000
	local i = `i' +1
}

*generate total moving averages
tsset cow year
local i = `start'
while `i'<=`sec' {
	local z = `y'-1
	tssmooth ma a`i'_`y'  = a`i', window(`z' 1 0)
	local i = `i' +1
}

*generate per capita moving averages
tsset cow year
local i = `start'
while `i'<=`sec' {
	local z = `y'-1
	tssmooth ma a`i'_`y'pc = a`i'_pc, window(`z' 1 0)
	local i = `i' +1
}

*label per capita totals
local i =`start'
foreach x of local name {
	label var a`i'_pc "`x' aid per capita (millions USD, constant)"
	local i = `i' +1
}

*label per capita moving averages
local i =`start'
foreach x of local name {
	label var a`i'_`y'pc "`x' aid per capita `y'-year MA (millions USD, constant)"
	local i = `i' +1
}

*label moving averages
local i =`start'
foreach x of local name {
	label var a`i'_`y' "`x' aid  `y'-year MA (millions USD, constant)"
	local i = `i' +1
}

*generate year-totals and year-averages*
local i = `start'
while `i'<=`sec' {
	bysort year: egen a`i'_yr_total=total(a`i'_`y')  /*total sum*/
	local i = `i' +1
}
local i = `start'
while `i'<=`sec' {
	bysort year: egen a`i'_yr_ave=mean(a`i'_`y'pc)   /*per capita average*/
	local i = `i' +1
}

**Figure 1A: Economic Aid over time**
label var a15_yr_total "Total"
label var a15_yr_ave "Average per capita"
twoway (bar a15_yr_total year, yaxis(1) ylabel(0 (10000) 40000) ytitle("Total, constant USD (millions)") xscale(range(1990 2008))) /*
*/ (line a15_yr_ave year, yaxis(2) ylabel(0(20)100, axis(2)) legend(pos(12) col(3) ring(2)) ) /*
*/ if year>1988 & year<2009,  xtitle("Year")	xlabel(1990 (2) 2008)
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\Figure1A.pdf", as(pdf)  replace


**Figure 1B: Democracy Aid over time**
label var a2_yr_total "Total"
label var a2_yr_ave "Average per capita"
twoway (bar a2_yr_total year, yaxis(1) ylabel(0 (500) 3000) ytitle("Total, constant USD (millions)") xscale(range(1990 2008))) /*
*/ (line a2_yr_ave year, yaxis(2) ylabel(1 (1) 6, axis(2)) legend(pos(12) col(3) ring(2)) ) /*
*/ if year>1988 & year<2009,  xtitle("Year")	xlabel(1990 (2) 2008)
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\Figure1B.pdf", as(pdf)  replace


**Figure 2: US Democracy Assistance and Civil Society Aid**
use AidDatav192, clear
set scheme lean1
keep if (cow>=400 & cow<600) | cow==625
sort cow year
merge cow year using AidDatav192_USprojects
tab _merge
tsset cow year
bysort year: egen sum_us=total(usdemoc_com_const)
bysort year: egen sum_dem=total(democ_com_const)
bysort year: egen sum_tot=total(total_com_const)
bysort year: egen sum_civ=total(dem_civilsoc_com_const)
bysort year: egen sum_gov=total(dem_government_com_const)
gen sh_us = sum_us/sum_dem
gen sh_civ = sum_civ/sum_dem
gen sh_dem = sum_dem/sum_tot
gen sh_us2 = sh_us*sh_dem
gen sh_civ2 = sh_civ*sh_dem
egen tagy= tag(year)
keep if tagy==1
tssmooth ma us = sh_us, window(1 1 1)
tssmooth ma dem = sh_dem, window(1 1 1)
tssmooth ma us2 = sh_us2, window(1 1 1)
tssmooth ma civ2 = sh_civ2, window(1 1 1)

twoway(bar dem   us2 year if year>1988 & year<2009, yaxis(1)   legend(label(1 "DGA") /*
*/ label(2 "U.S. DGA")  pos(12) col(2) ring(2)) /*
*/ ytitle("Percent of Total Aid") xtitle("Year") xlabel(1990 (2) 2008) ylabel(0 (0.02) .1) )
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\Figure2A.pdf", as(pdf)  replace


twoway(bar dem civ2 year if year>1988 & year<2009, yaxis(1)   legend(label(1 "DGA") /*
*/ label(2 "Civil society aid")  pos(12) col(2) ring(2)) /*
*/ ytitle("Percent of Total Aid") xtitle("Year") xlabel(1990 (2) 2008) ylabel(0 (0.02) .1) )
graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\Figure2B.pdf", as(pdf)  replace

********************************
