
set more off


**** Create instruments: donor characteristic weighted by distance to recipient ****
cd "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Replication data files\distance"
qui do inst_weight_dist
 
**** Multi-Partyism data ****
use cg_original, clear
keep cowcode entryy
keep if (cowcode>=402 & cowcode<=591) | cowcode==625
egen tag  = tag(cowcode)
keep if tag==1
gen spell = 2008-entryy+1 
expand spell
sort cow
egen min = min(_n), by(cow)
gen year = entryy if min==_n
replace year = year[_n-1] +1 if year==. & year[_n-1] ~=.  & cow==cow[_n-1]
order cow year
drop tag spell min
sort cow year
saveold temp1, replace

use rawmp, clear
gen case =_n
egen casea= concat(country start), punct(" ")
egen casename =concat(casea end), punct("-")
drop casea
gen spell = end-start +1
expand spell
sort case
egen min =min(_n), by(case)
gen year = start if min==_n
sort case year
bysort case: replace year = year[_n-1] +1 if year==. & year[_n-1] ~=.  & case==case[_n-1]
drop min spell
gen mp=1 if start==year
sort cow year
replace mp=1 if mp[_n-1]==1 & cow[_n-1]==cow & year<end
replace mp=1 if mp[_n-1]==1 & cow[_n-1]==cow & year==2008 /*right censored*/
replace mp=0 if end==year  & year~=2008
replace mp =0 if year==2008 & cow == 435 /*MP fail in 2008 in Mauritania*/
sort cow year
merge cow year using temp1
tsset cow year
tssmooth ma tyear = year, window(0 0 1)
tssmooth ma tstart = start, window(0 0 1)
replace mp=1 if  tyear == tstart & mp==. & cow==cow[_n-1] & tyear~=.
recode mp (.=0)
tsset cow year
gen lmp = l.mp
replace lmp=1 if cow==436 & (year==1997 | year==2000) /*treat as start of new multiparty period, not as transition to mparty*/
egen minmp = min(year) if mp==1, by(case)
replace minmp= minmp
gen dmp = 1 if minmp==year 
sort case year
replace dmp =dmp[_n-1] +1 if dmp==. & dmp[_n-1]~=. & year<=end   & case==case[_n-1] & lmp==1
gen dnmp =1 if entry == year & lmp~=1
tsset cow year
replace dnmp=1 if lmp==0 & l.lmp==1
replace dnmp =dnmp[_n-1] +1 if dnmp==. & dnmp[_n-1]~=.   & cow==cow[_n-1] & lmp==0
keep if year>1988
tab mp if _merge==1 /*should be all zeros*/
drop _merge entry start end tyear tstart min* case
recode dnmp dmp (.=0)
gen dnmp2 = dnmp^2
gen dnmp3= dnmp^3
gen dmp2 = dmp^2
gen dmp3= dmp^3
tsset cow year
saveold temp, replace

**** Merge with control variables ****
use africa_data2, clear
tsset cow year
 
**** Add IMF program participation ****
sort cow year
merge cow year using IMFprogram
tab _merge
drop if _merge==2
drop _merge
sort cow year
 
**** AID DATA transformations ****
 local y = 3 /*set moving average to observation year + y-1 years*/
 local name  "Soc Demo Infr  Prod  Envi BS Comm Debt Emerg NG0 Admin Refug  Totc Totd"
 local start = 1  /*marks which sector to start with in the list of sectors in `name'*/
 local sec= 17   /*number of sectors should equal number of labels in `name'*/
 
 /*Sectors
 soc_com_const democ_com_const ecinfra_com_const prod_com_const envirmultisec_com_const 
 bs_com_const commod_com_const debt_com_const emerg_com_const NGO_com_const 
 donoradmin_com_const refugdonor_com_const unalloc_com_const
 total_com_const total_disb_const
 */
 gen a1 = soc_com_const
 gen a16 = dem_civilsoc_com_const
 gen a17 = dem_government_com_const
 gen a2 = a16 + a17     				/* all democracy aid */
 gen a3 = ecinfra_com_const
 gen a4 = prod_com_const
 gen a5 = envirmultisec_com_const
 gen a6 = bs_com_const  				 
 gen a7 = commod_com_const
 gen a8 = debt_com_const
 gen a9 = emerg_com_const
 gen a10 = NGO_com_const
 gen a11 = donoradmin_com_const
 gen a12 = refugdonor_com_const
 gen a13 = total_com_const  
 gen a14 = total_disb_const
 gen a15 = a13-a2-a12  					/*all aid except democracy aid and refugee aid */
 
 *generate per capita totals
 local i = `start'
 while `i'<=`sec' {
 	gen a`i'_pc = a`i'/(pwt7_pop*1000)
 	local i = `i' +1
 }
 
 *generate per capita lagged moving averages
 tsset cow year
 local i = `start'
 while `i'<=`sec' {
 	tssmooth ma a`i'_`y'pc = a`i'_pc, window(`y' 0 0)
 	local i = `i' +1
}

 *log transform
 tsset cow year
 local i = `start'
 while `i'<=`sec' {
 	replace a`i'_`y'pc = ln(1+a`i'_`y'pc)
 	local i = `i' +1
}
gen demaid  = a2_`y'pc
gen econaid = a15_`y'pc
gen civaid  = a16_`y'pc
gen govaid  = a17_`y'pc
drop tag


**** Instrument set merge ****
sort cow year
merge cow year using instrument_merge 
drop if year>2008
tab _merge
drop _merge
sort cow year
 
**** Merge back with multiparty data ****
sort cow year
merge cow year using temp
tab _merge
drop _merge
 
**** Generate 3-yr lag moving average for instruments ****
local y = "3"
local f = "Iwip Iinfl"
foreach z of local f {
	tssmooth ma  `z'`y' =  `z', window(`y' 0 0)
}
**** Variable construction ****
tsset cow year
gen lgdp = l.pwt7_lgdp
gen gr = pwt7_lag12
gen lpop = ln(l.pwt7_pop)
tssmooth ma civilwar3 = prio_conflict_intra, window (2 0 0)
gen time = year-1989
gen time2 = time^2
saveold temp, replace

**** merge OECD trade data ****
*do CleanOECDTrade                            / * just use trade.dta for replication; this was created from CleanOECDTrade.do and IMFtrade.dta */
use temp, clear
sort cowcode year
merge cowcode year using trade
tab _merge
drop if _merge==2
drop _merge
gen tr = ln(1+oecdtrade)
tssmooth ma tr3=  tr, window(3 0 0)
tsset cow year
gen trade = l.tr3
sort cow year
saveold temp, replace


**** merge NGO/INGO data ****  These are INGOs and NGOs present in the recipient country
use temp, clear
sort cowcode year
merge cowcode year using ingos
tab _merge
drop if _merge==2
drop _merge
local var  = "igo ngo tot"
foreach x of local var {
	replace `x'_TOTAL11=  `x'_TOTAL11/pwt7_pop
	egen y`x'=  mean(`x'_TOTAL11), by(cow)
	egen m`x'  = max(y`x'), by(cow)
	gen  `x'  =   ln(1+m`x')
}
rename tot org
sort cow year
saveold temp, replace

**** merge IO membership data ****  These are number of IOs to which the recipient belongs
use temp, clear
sort cowcode year
merge cowcode year using igocount
tab _merge
drop if _merge==2
drop _merge
tssmooth ma io3count = total_io, window(3 0 0)
tsset cow year
sort cow year
saveold temp, replace

**** merge OECD alliance data ****
use temp, clear
sort cowcode year
merge cowcode year using alliance_oecd
tab _merge
drop if _merge==2
drop _merge
gen oecdally = defense + neutrality + nonaggression
recode oecdally (.=0)
tssmooth ma ally`y'=  oecdally, window(`y' 0 0)
gen ally = ln(1+ally`y')
tsset cow year
sort cow year
saveold temp, replace

**** merge OECD foreign stock data ****
use temp, clear
sort cowcode year
merge cowcode year using stockforeign_oecd
tab _merge
drop if _merge==2
drop _merge
egen mstockforeign= mean(stockforeign), by(cow)
replace  mstock = ln(1+mstock)
egen stock= max(mstock), by(cow)
tsset cow year
sort cow year
saveold temp, replace


*****************************************************************************************
*  These 3 programs prepare a dataset for each of the 3 types of dependent variables:  	*
*  (1) multipartyism									*
*  (2) electoral misconduct								*
*  (3) vote shares									*
*****************************************************************************************

capture program drop prep1
program prep1
	set more off
	use RossOil2009, clear     	/* Oil from Ross 2009 data set at Dataverse */
	egen c = group(id)
	tsset c year 
	gen oil= ln(1+l.oil_gas_valuePOP_2000)
	keep cty_name year oil  
	drop if year<1985
	gen cowcode =.
	rename cty_name country
	qui do cowcodes
	drop if cow==.
	sort cow year
	merge cow year using temp
	tab _merge   			/* missing for STP and SEY */
	drop _merge
 	sort cow
	merge cow using ef  		/* Ethnic fractionalization from Posner AJPS 2004*/
	tab _merge
	drop _merge
	gen yr1 = year<1994
	gen yr2 = year>=1994 & year<1999
	gen yr3 = year>=1999 & year<2004
	gen yr4 = year>=2004
	gen cwar =  (prio_lconflict_intra>0) * prio_lconflict_cumint
	gen small = cia_area<2100
	sort cow year
end

capture program drop prep2
program prep2
		set more off
		use neldav3_new, clear
		sort cow year
		merge cow year using temp
		tab _merge
		drop if _merge==1
		drop _merge
		sort cow
		merge cow using ef  /* Ethnic fractionalization from Posner AJPS 2004*/
		tab _merge
		drop if _merge==2
		drop _merge
		gen n3_first = nelda2=="yes" if nelda2~=""
		gen n3_expectwin = nelda12=="yes" if nelda12~=""
		gen n3_monitor = nelda45=="yes" if nelda45~=""
		gen n3_violence = nelda31=="yes" | nelda33=="yes" if nelda31~="" & nelda33~=""
		gen n3_observeunfair = n3_prev==1 | n3_harass==1 | n3_violence==1 if   n3_harass~=. & n3_prev~=. & n3_violence~=.
		egen harass = max(n3_observeunfair) , by(country year) /* for all types and all rounds*/
		egen monitor=max(n3_monitor), by(country year)
		egen h_p = max(n3_observeunfair) if t=="P", by(country year) /* for all types and all rounds*/
		egen h_l = max(n3_observeunfair) if t=="L", by(country year) /* for all types and all rounds*/
		egen harass_p = max(h_p), by(country year) 
		egen harass_l = max(h_l), by(country year) 
		egen prevent = max(n3_prev), by(country year)
		egen oharass = max(n3_harass), by(country year)
		egen first = max(n3_first), by(country year)
		egen expectwin = max(n3_expect), by(country year)
		egen boycott =max(n3_opposboycott) if n3_opposboycott~=., by(country year)
		egen cy_tag = tag(cow year)  /*analyze just one country-year ob*/
		keep if cy_tag==1
		tsset cow year 
		tssmooth ma harass_l1 = harass, window(1 0 0)
		tssmooth ma harass_f1 = harass, window(0 0 1)
		qui probit harass demaid econaid gdp lpop civilwar3 time time2  if mp==1 & cy_tag==1  
		gen pres = t=="P"
		gen small = cia_area<2100
		keep if e(sample)
		tab harass
end

capture program drop prep3
program prep3
	use neldav3_new, clear
	sort cow year
	merge cow year using temp
	tab _merge
	drop if _merge==1
	drop _merge
	gen n3_observeunfair =n3_prev==1 | n3_harass==1   if   n3_harass~=. & n3_prev~=.  
	egen harass = max(n3_observeunfair) , by(country year) /* for all types and all rounds*/
	egen h_p = max(n3_observeunfair) if t=="P", by(country year) /* for pres and all rounds*/
	egen h_l = max(n3_observeunfair) if t=="L", by(country year) /* for pres and all rounds*/
	egen harass_p = max(h_p), by(country year) 
	egen harass_l = max(h_l), by(country year) 
	egen bias = max(n3_mbias), by(country year)
	egen prevent = max(n3_prev), by(country year)
	egen oharass = max(n3_harass), by(country year)
	egen boycott =max(n3_opposboycott) if n3_opposboycott~=., by(country year)
	egen tag = tag(cow year)  /*analyze just one country-year ob*/
	drop if tag==0
	sort cow year
	merge cow year using  IncumbentVote
	tab _merge
	gen shareopp = logit(1-incshare)
	twoway scatter shareopp incshare
	gen ldmp =  ln(1+dmp)
	gen ltime = ln(1+time)
 	keep if shareopp~=. & year>=1989 & mp==1 & dmp>0
 	replace vote =87.93 if cow==530 & year==2000 /*translate Ethiopia's seats to votes */
 	replace vote =59.78 if cow==530 & year==2005 /*translate Ethiopia's seats to votes */
 	gen voteopp = logit((100-votepercent)/100)
 end
 
 **************
