
***********************************************************
** Probe exogeneity assumption for `outside' instruments **
** Date: 2/25/14										 **
** Author: jgw											 **
***********************************************************

* general set up
    clear
	clear matrix
	clear mata
	set maxvar 30000

* read code provided by Hansen, http://faculty.chicagogsb.edu/christian.hansen/research/plausexog.zip
    *quietly do "uci.ado"
	
***************************
** Multiparty transition **
***************************
	
* clean data, set globals 
	prep1
	set seed 487552
	global c = "lgdp lpop cwar dnmp dnmp2 dnmp3"
	global x = "econaid"
	global y = "mp"

* find max F-stat with Lewbel instruments 
	ivreg2h mp ($x =Iwip3 ) $c if lmp==0, cluster(cow) first gen  /* generate Lewbel instruments */
	keep if e(sample)
	local lew = "econaid_lgdp_g econaid_lpop_g econaid_cwar_g econaid_dnmp_g econaid_dnmp2_g econaid_dnmp3_g"
	foreach x of local lew {	
		qui reg $x $c Iwip3  `x', cluster(cow)
		test Iwip3  `x'
	}

* set global instrument set  : use only a maximum of 6 excluded instruments so drop civwar Lewbel instrument
	global i = "Iinfl3 econaid_lgdp_g econaid_lpop_g  econaid_dnmp_g econaid_dnmp2_g econaid_dnmp3_g"

* OLS estimate
	qui reg $y $x $c, cluster(cow)
	lincom $x

* 2SLS estimate
	ivreg2 $y ($x = $i) $c, cluster(cow)  ffirst orthog(Iinfl3)
	
* show that 2SLS SE with clustered errors are much smaller than 2SLS SE with no cluster
	qui ivreg2 $y ($x = $i) $c, cluster(cow)  
	lincom $x, level(90)
	qui ivreg2 $y  ($x =$i) $c 
	lincom $x, level(90)

* reduced form
	qui reg $y  $i $c    
	lincom Iinfl3 , level(90)
	qui reg $y $x $i $c    
	lincom Iinfl3 , level(90)


* unified confidence interval for uniform, symmetric gammas
gen hi = .
gen lo =.
gen med=.
gen index=.
local i = 1
forval y = 1/40 {
	local x = `y'/1000
	replace index=`x' if _n==`i'
	qui uci $y ($x $c = $i $c), g1min(-`x') g1max(`x') g2min(0) g2max(0) g3min(0) g3max(0) g4min(0) g4max(0) g5min(0) g5max(0) g6min(0) g6max(0)   inst($i) grid(2) level(.90) cluster(cow)
 	matrix v= e(V)
	matrix b = e(b)
	scalar se = sqrt(v[1,1])
	scalar beta = b[1,1]
	replace hi = beta + 1.645*se if _n==`i'
	replace med = beta if _n==`i'
	replace lo = beta - 1.645*se if _n==`i'
	local i = `i' + 1
}
twoway (line hi index, lpattern(dash) ytitle("{it: Economic aid}")) (line med index, lpattern(solid) xtitle("{&gamma} ")) (line lo index, yline(0, lpatter(shortdash)) lpattern(dash)) , /*
*/  legend(label (1  "upper 90% interval") label (2  "estimate")  label (3  "lower 90% interval")   pos(12) col(3) ring(1))
	graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\ExoTransition.pdf"  , as(pdf)   replace
	
	**************************************************************
	*Test monotonicity assumption: Is there homogenous treatment?*
	**************************************************************
	qui prep1
	global c = "lgdp lpop cwar dnmp dnmp2 dnmp3"
	global x = "econaid"
	global y = "mp"
	qui ivreg2h mp ($x =Iinfl3) $c if lmp==0, cluster(cow) first gen  /* generate Lewbel instruments */
	lincom $x
	keep if e(sample)
	set seed 78689
	gen r= runiform()
	global i = "Iinfl3 econaid_lpop_g econaid_dnmp_g econaid_dnmp2_g econaid_dnmp3_g"

* first stage tests on 2 (exclusive) random subsets of the data
	qui reg $x $c $i , cluster(cow)
	test $i
	qui reg $x $c $i if r<=.5, cluster(cow)
	test $i
	qui reg $x $c $i if r>.5, cluster(cow)
	test $i

* first stage tests for two 2-way divisions of the sample in time and space
	qui _pctile year, p(50)
	return list
	local x = r(r1)
	qui reg $x $c $i if year>= `x', cluster(cow) 
	test $i
	qui reg $x $c $i if year<=`x', cluster(cow) 
	test $i
	qui _pctile cow, p(50)
	return list
	local x = r(r1)
	qui reg $x $c $i  if cow>=`x', cluster(cow) 
	test $i
	qui reg $x $c $i  if cow<=`x', cluster(cow) 
	test $i
			* All F-tests>9 *
			

************************
** Multiparty failure **
************************
	
* clean data, set globals 
	prep1
	set seed 11162008
 	global c = "lgdp lpop cwar dmp dmp2 dmp3"
	global x = "demaid"
	global y = "mp"

* find max F-stat with Lewbel instruments 
    ivreg2h mp ($x =Iwip3 ) $c if lmp==1, cluster(casename) first gen  /* generate Lewbel instruments */

* set global instrument set
	global i = "Iwip3  demaid_lgdp_g demaid_lpop_g demaid_dmp_g demaid_dmp2_g demaid_dmp3_g"

* OLS estimate
	qui reg $y $x $c, cluster(casename)
	lincom $x

* 2SLS estimate
	ivreg2 $y ($x = $i) $c, cluster(casename)  ffirst orthog(Iwip3 )
	
* reduced form
	qui reg $y $i $c    
	lincom Iwip3  , level(90)
	qui reg $y $x $i $c    
	lincom Iwip3  , level(90)
	
* unified confidence interval for uniform, symmetric gammas
gen hi = .
gen lo =.
gen med=.
gen index=.
local i = 1
forval y = 1/40 {
		local x = `y'/10000
		qui replace index=`x' if _n==`i'
		qui uci $y ($x $c = $i $c), g1min(-`x') g1max(`x') g2min(0) g2max(0) g3min(0) g3max(0) g4min(0) g4max(0) g5min(0) g5max(0) g6min(0) g6max(0)   inst($i) grid(2) level(.90) cluster(casename)
		matrix v= e(V)
		matrix b = e(b)
		scalar se = sqrt(v[1,1])
		scalar beta = b[1,1]
		qui replace hi = beta + 1.645*se if _n==`i'
		qui replace med = beta if _n==`i'
		qui replace lo = beta - 1.645*se if _n==`i'
		local i = `i' + 1
}

twoway (line hi index, lpattern(dash) ytitle("{it: Democracy aid}")) (line med index, lpattern(solid) xtitle("{&gamma} ")) (line lo index, yline(0, lpatter(shortdash)) lpattern(dash)) , /*
*/  legend(label (1  "upper 90% interval") label (2  "estimate")  label (3  "lower 90% interval")   pos(12) col(3) ring(1))
	graph export "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Manuscript files\ExoFailure.pdf"  , as(pdf)  replace
	
	**************************************************************
	*Test monotonicity assumption: Is there homogenous treatment?*
	**************************************************************
	qui prep1 
	replace mp =mp*100
	global c = "lgdp lpop cwar dmp dmp2 dmp3"
	global x = "demaid"
	global y = "mp"
	qui ivreg2h mp ($x =Iwip3 ) $c if lmp==1, cluster(casename) first gen  /* generate Lewbel instruments */
	lincom $x
	keep if e(sample)
	set seed 982749
	gen r= runiform()
	global i = "Iwip3  demaid_lpop_g demaid_dmp_g demaid_dmp2_g demaid_dmp3_g"

* first stage tests on 2 (exclusive) random subsets of the data
	qui reg $x $c $i , cluster(casename)
	test $i
	qui reg $x $c $i if  r<=.50, cluster(casename)
	test $i
	qui reg $x $c $i if r>.50, cluster(casename)
	test $i
	 
* first stage tests for two 2-way divisions of the sample in time and space
	qui _pctile year, p(50)
	return list
	local x = r(r1)
	qui reg $x $c $i if year>= `x', cluster(casename) 
	test $i
	qui reg $x $c $i if year<=`x', cluster(casename) 
	test $i
	qui _pctile cow, p(50)
	return list
	local x = r(r1)
	qui reg $x $c $i  if cow>=`x', cluster(casename) 
	test $i
	qui reg $x $c $i  if cow<=`x', cluster(casename) 
	test $i
			* All F-tests>12 *

 
