
/*
Weighting instruments by distance
Insert list of all original.dta files
AUTHOR: Simone Dietrich
ORIGIN DATE: 12.17.13
LAST UPDATE: 5.5.14
*/ 
 
**Begin**
set more off
use aiddata_dyadic-merge, clear
drop if donor=="ACBF" | donor=="AFDB" | donor=="AFDF" | donor=="AFESD" | donor=="AFESD" | donor=="BADEA" | donor=="CAF" | donor=="CDB" | donor=="GAVI" | donor=="GEF" | donor=="IADB" | donor=="IFAD"| donor=="NDF" | donor=="NTF" | donor=="OPEC" 
sort cowcode_don cowcode_rec year
save aiddata_dyadic-merge2.dta, replace


use distance, clear
replace ccode1=255 if ccode1==260
replace year=1970 if year==2004
sort ccode1 ccode2 year
duplicates tag ccode1 ccode2 year, g(tag)
tab tag
tab ccode2 if tag==1
rename ccode1 cowcode_don 
rename ccode2 cowcode_rec 
save distance1970-merge, replace

use aiddata_dyadic-merge2.dta, clear
sort cowcode_don cowcode_rec year
merge m:1 cowcode_don cowcode_rec year using distance1970-merge
gen dyadid=(cowcode_don*1000) + cowcode_rec
sort dyadid year
by dyadid: carryforward distance, gen(distancefor)
tab recipient if distancefor==.

*multilateral donor organizations for instrument weighting

*European community
gen EC_don=0
replace EC_don=1 if donor=="EC"

*UN WB and IMF
gen UN_don=0
replace UN_don=1 if donor=="IDA"
replace UN_don=1 if donor=="IBRD"
replace UN_don=1 if donor=="IFC"
replace UN_don=1 if donor=="IMF"
replace UN_don=1 if donor=="GEF"
replace UN_don=1 if donor=="GFATM"
replace UN_don=1 if donor=="AFDF"
replace UN_don=1 if donor=="UNDP"
replace UN_don=1 if donor=="UNICEF"
replace UN_don=1 if donor=="UNAIDS"
replace UN_don=1 if donor=="UNFPA"
/*
*other multilaterals
gen OTHER_don=0
replace OTHER_don=1 if WBIMF_don==0 &  UN_don==0 & EC_don==0 & cowcode_don==1
tab donor if EC_don==1
tab donor if WBIMF_don==1
tab donor if UN_don==1
tab donor if OTHER_don==1 
*/
gen b=0
replace b=1 if cowcode_don==211
gsort cowcode_rec -b
by cowcode_rec: gen ECdist=distancefor[1]
sort cowcode_don cowcode_rec year
replace ECdist = . if donor!="EC"
sort donor recipient year
replace distancefor=ECdist if donor=="EC"


gen u=0
replace u=1 if cowcode_don==2
gsort cowcode_rec -u
by cowcode_rec: gen UNdist=distancefor[1]
sort cowcode_don cowcode_rec year
replace UNdist =. if UN_don~=1
sort donor recipient year
list recipient if donor=="UNFPA" & UNdist==.
replace distancefor=UNdist if UN_don==1
gen lndistance=log(distancefor)

drop if year<1985
sort cowcode_don year
drop _merge
**merge in donor variables for weighting: inflation, wip

*WDI inflation
sort cowcode_don year
merge m:1 cowcode_don year using wdidonors
tab donor if _merge==1
drop _merge

bysort year: egen UN_inflT=mean(inflat) if cowcode_don==2 | cowcode_don==200 | cowcode_don==220 | cowcode_don==255 | cowcode_don==740
bysort year: egen UN_infl=max(UN_inflT)
bysort year: egen EC_inflT=mean(inflat) if cowcode_don==200 | cowcode_don==220 | cowcode_don==255
bysort year: egen EC_infl=max(EC_inflT)
drop  UN_inflT EC_inflT 
drop  GCBALCASHGDZS NYGDPDEFLKDZG
sort cowcode_don year

label var UN_infl "Average inflation for major 5 countries (US, UK, France, Germany, Japan) for WB, IMF, UN aid"
label var EC_infl "Average inflation for major 3 EU countries (UK, France, Germany) for EC aid"

*Women in parliament (wip)
sort cowcode_don year
merge m:1 cowcode_don year using WomenParl
tab donor if _merge==1
drop _merge

*copy average values to IOs
bysort year: egen UN_wip=max(UN_wip1)
bysort year: egen EC_wip=max(EC_wip1)
drop UN_wip1 EC_wip1 /*OECD_wip1*/
drop if year<1985 & dyadidyr==.
label var UN_wip "Average wip for major 5 countries (US, UK, France, Germany, Japan)for WB, IMF, UN aid"
label var EC_wip "Average wip for major 3 EU countries (UK, France, Germany) for EC aid"

*duplicates list
drop if dyadid==.
save temp1, replace

*Weighting donor variables by distance
use temp1, clear

egen cydist = sum(1/distancefor), by(cowcode_rec year)   /* invert distance so closer is weighted more */
gen DistShare = (1/distancefor)/cydist			/* weight by the share of total distance by all donors for a given recipient in a given year */
local x2 inflat wip 
local z2 inf wip 
forval i = 1/2 {
	local x : word `i' of `x2'
	local z : word `i' of `z2' 
	foreach y in DistShare {
		gen wt`x'_`y'_bm=`x' *(`y') if cowcode_don~=1
		replace wt`x'_`y'_bm=UN_`z' *(`y')  if UN_don==1
		replace wt`x'_`y'_bm=EC_`z' *(`y')  if EC_don==1
	}
}

 
local u = "inflat wip"
foreach z of local u {
	egen I`z' = sum(wt`z'_DistShare_bm), by(cowcode_rec year)
}
egen tagcw = tag(cowcode_rec year) 
keep if tagcw==1
rename Iinfl Iinfl 
 
sum I* year
rename cowcode_rec cowcode
keep cowcode year  I*
cd "C:\Users\jwright\Documents\My Dropbox\Research\UNWider\2013 files\DietrichWrightJOP\Replication data files"
sort cow year
save instrument_merge, replace
